//
//
// @author Michael Liljenstam, ISTS, Dartmouth College
//
// $Id: TestWormEpidemicInitializer.java,v 1.1 2003/03/02 20:34:20 mili Exp $

package SSF.App.Worm.test;

import SSF.App.Worm.*;

import java.util.*;


/**
 *  Initialize worm epidemic with for tests. Two specific ASes are assigned 
 *  all susceptibles (30/70% split) and cross-strata infection parameters are 
 *  set uniformly.
 */
public class TestWormEpidemicInitializer extends WormEpidemicInitializer {

    /** 
     *  Perform the initialization.
     */
    public void doInit() {
	ASGraph asGraph = MacroscopicModel.ref.net;
	int numASs = asGraph.numASs;

	float Beta = MacroscopicModel.ref.wormModel.Beta;
	float sTot = MacroscopicModel.ref.wormModel.sTot;
	float iTot = MacroscopicModel.ref.wormModel.iTot;
	float rTot = MacroscopicModel.ref.wormModel.rTot;

	// init infection parameters
	float[] BetaJ  = new float[numASs];
	MacroscopicModel.ref.wormModel.BetaJ = BetaJ;
	for (int j = 0; j < numASs; j++) {
	    BetaJ[j] = Beta / numASs; // Uniform distr of IPs
	} // for

	// init susceptibles (30% to one, 70% to the other)
	if (numASs == 1) {
	    System.err.println("ERROR: TestWormEpidemicInitializer requires stratified epidemic model\n");
	    System.exit(-1);
	}
	int thirtyPercSusc = (int) Math.round(sTot * .3);
	asGraph.ases[asGraph.asnToIndex(557)].wormModel.s = thirtyPercSusc;
	asGraph.ases[asGraph.asnToIndex(1351)].wormModel.s = 
	    (int)(sTot-thirtyPercSusc);

	// init initially infected	    
	asGraph.ases[0].wormModel.i = iTot; // all initally infected in AS 0

	if (MacroscopicModel.ref.wormModel.DEBUG) {
	    System.out.println("Init worm epidemic model: s=" 
			       + sTot + ", i=" + iTot + ", r=" + rTot
			       + ", Beta=" + Beta);
	}
    } // doInit()
}
